@@ -381,7 +381,7 @@ static int set_ctl_value(struct space *space, const char *value, int all)
 				snd_ctl_elem_value_set_integer(space->ctl_value, idx, val);
 			} else if (items > 2 && value[items-2] == 'd' && value[items-1] == 'B') {
 				val = strtol(value, NULL, 0) * 100;
-				if ((pos2 = index(value, '.')) != NULL) {
+				if ((pos2 = strchr(value, '.')) != NULL) {
 					if (isdigit(*(pos2-1)) && isdigit(*(pos2-2))) {
 						if (val < 0)
 							val -= strtol(pos2 + 1, NULL, 0);
@@ -396,7 +396,7 @@ static int set_ctl_value(struct space *space, const char *value, int all)
 				}
 				val = snd_ctl_convert_from_dB(snd_hctl_ctl(space->ctl_handle), space->ctl_id, val, &lval, -1);
 				if (val < 0) {
-					Perror(space, "unable to convert dB value '%s' to internal integer range", value);
+					dbg("unable to convert dB value '%s' to internal integer range", value);
 					return val;
 				}
 				snd_ctl_elem_value_set_integer(space->ctl_value, idx, lval);
@@ -929,6 +929,7 @@ static void apply_format(struct space *space, char *string, size_t maxsize)
 		SUBST_ATTR,
 		SUBST_SYSFSROOT,
 		SUBST_ENV,
+		SUBST_CONFIG,
 	};
 	static const struct subst_map {
 		char *name;
@@ -941,6 +942,7 @@ static void apply_format(struct space *space, char *string, size_t maxsize)
 		{ .name = "attr",	.fmt = 's',	.type = SUBST_ATTR },
 		{ .name = "sysfsroot",	.fmt = 'r',	.type = SUBST_SYSFSROOT },
 		{ .name = "env",	.fmt = 'E',	.type = SUBST_ENV },
+		{ .name = "config",	.fmt = 'g',	.type = SUBST_CONFIG },
 		{ NULL, '\0', 0 }
 	};
 	enum subst_type type;
@@ -1101,6 +1103,16 @@ found:
 			dbg("substitute env '%s=%s'", attr, pos);
 			strlcat(string, pos, maxsize);
 			break;
+		case SUBST_CONFIG:
+			if (attr == NULL) {
+				dbg("missing attribute");
+				break;
+			}
+			pair = value_find(space, attr);
+			if (pair == NULL)
+				break;
+			strlcat(string, pair->value, maxsize);
+			break;
 		default:
 			Perror(space, "unknown substitution type=%i", type);
 			break;
@@ -1253,7 +1265,7 @@ static char *new_root_dir(const char *filename)
 
 	res = strdup(filename);
 	if (res) {
-		tmp = rindex(res, '/');
+		tmp = strrchr(res, '/');
 		if (tmp)
 			*tmp = '\0';
 	}
@@ -1313,10 +1325,9 @@ static int parse_line(struct space *space, char *line, size_t linesize)
 				}
 				snprintf(string, sizeof(string), "%i", err);
 				space->program_result = strdup(string);
-				if (err < 0 || space->program_result == NULL) {
-					err = 0;
+				err = 0;
+				if (space->program_result == NULL)
 					break;
-				}
 			} else if (op == KEY_OP_MATCH || op == KEY_OP_NOMATCH) {
 				dbg("ctl match: '%s' '%s'", value, attr);
 				temp = (char *)elemid_get(space, attr);
@@ -1521,15 +1532,23 @@ static int parse_line(struct space *space, char *line, size_t linesize)
 		}
 		if (strncasecmp(key, "ACCESS", 6) == 0) {
 			if (op == KEY_OP_MATCH || op == KEY_OP_NOMATCH) {
+				if (value[0] == '$') {
+					strlcpy(string, value, sizeof(string));
+					apply_format(space, string, sizeof(string));
+					if (string[0] == '/')
+						goto __access1;
+				}
 				if (value[0] != '/') {
 					strlcpy(string, space->rootdir, sizeof(string));
 					strlcat(string, "/", sizeof(string));
 					strlcat(string, value, sizeof(string));
 				} else {
-					strlcat(string, value, sizeof(string));
+					strlcpy(string, value, sizeof(string));
 				}
+				apply_format(space, string, sizeof(string));
+			      __access1:
 				count = access(string, F_OK);
-				dbg("access(%s) = %i", value, count);
+				dbg("access(%s) = %i (%s)", string, count, value);
 				if (op == KEY_OP_MATCH && count != 0)
 					break;
 				if (op == KEY_OP_NOMATCH && count == 0)
